# eric7.Preferences.ConfigurationPages.PrinterPage

Module implementing the Printer configuration page.

### Global Attributes

None

### Classes

PrinterPage | Class implementing the Printer configuration page.

### Functions

create | Module function to create the configuration page.

## PrinterPage

Class implementing the Printer configuration page.

### Derived from

ConfigurationPageBase, Ui_PrinterPage

### Class Attributes

None

### Class Methods

None

### Methods

PrinterPage | Constructor
on_printheaderFontButton_clicked | Private method used to select the font for the page header.
polishPage | Public slot to perform some polishing actions.
save | Public slot to save the Printer configuration.

### Static Methods

None

#### PrinterPage (Constructor)

PrinterPage()

Constructor

#### PrinterPage.on_printheaderFontButton_clicked

on_printheaderFontButton_clicked()

Private method used to select the font for the page header.

#### PrinterPage.polishPage

polishPage()

Public slot to perform some polishing actions.

#### PrinterPage.save

save()

Public slot to save the Printer configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up